#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(

    name = "tkRAD",

    version = "1.6.1-captain-hook",

    packages = ["tkRAD", "tkRAD.core", "tkRAD.easy", "tkRAD.widgets",
    "tkRAD.xml"],
    requires = ["Tkinter"],
    description = "tkRAD - Tkinter Rapid Application Development "
    "and XML widget builder",
    author = "Raphaël SEBAN",
    author_email = "motus@laposte.net",
    maintainer = "Raphaël SEBAN",
    maintainer_email = "motus@laposte.net",
    url = "https://github.com/tarball69/tkRAD/wiki",
    download_url = "https://github.com/tarball69/tkRAD",
    keywords = ["application", "framework", "tkinter", "gui", "xml",
    "widget", "builder"],
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "License :: OSI Approved",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Topic :: Software Development",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: User Interfaces",
    ],
    license = """
Licensed under GNU Lesser General Public License v3.
    """,
    long_description = """

Tkinter XML widget builder
--------------------------

*tkRAD* is a **Python3.2+** library designed to enable really Rapid
Application Development (RAD) process by using predefined classes to
derive in your own subclasses, with quite useful embedded services
such as dynamic **Tkinter XML widget building**, service manager,
events manager, RC configuration manager and so on.

*tkRAD* is a deliberately **short-made API** designed for comfort,
easiness and simplicity.

*tkRAD* provides the necessary **core tools** to quickly start up an
application development or for Tkinter widget testing through
*tkRAD.easy.builder* module.


**NEW** in tkRAD v1.6.1
-----------------------

* in `RADWindowBase`:

    * added new `confirm_quit()` hook method: now user confirmation
      dialog before quitting is customizable;


**NEW** in tkRAD v1.6
---------------------

* all project's source code has been reviewed to best comply with
  PEP8 (http://legacy.python.org/dev/peps/pep-0008/) recommendations;

* some minor bugs have been fixed:

    * in `RADXMLWidgetBase._tkRAD_font_support()`: font families long
      names now fully comply with tkinter's standard notation e.g.
      **font="'Times New Roman' 12 BoLd ITAlic"** conforms to
      **font="{times new roman} 12 bold italic"** which is the rightest
      notation ever;

    * in `RADXMLWidget._replace_alias()`: fixed a really stupid bug;

* added a new `RADWindowBase` ancestor class:

    * now `RADMainWindow` and `RADXMLMainWindow` directly inherit from
      this;

    * added new `RADWindow` and `RADXMLWindow` subclasses which use
      `TK.Toplevel` window instances instead of `TK.Tk` instances, as for
      main windows cited above;

    * these new toplevel windows are fairly more useful while working
      with templated objects such as Views and Forms, for example;

    * added a new hook method `RADWindowBase.on_quit_app()` to be
      reimplemented in subclass;

    * this hook method is called at the very last, just before really
      quitting app;

* direct `import tkRAD` statement now also imports the two new
  `RADWindow` and `RADXMLWindow` toplevel window classes;

* in package `tkRAD.core`:

    * added new module `async.py` which manages with **asynchronous
      tasks**;

    * this module supports atomic execution (neither called several
      times nor interrupted), automatic task re-scheduling and many other
      features;

    * added new module `database.py`, an SQLite lightweight database
      layer to make some easy data management;

    * it is highly recommended to use **subclasses** of
      `tkRAD.core.database.Database` wrapper class in your own projects,
      as this class only implements the really core methods to get things
      done;


**MAILING LIST**
----------------

For help and support on tkRAD, please feel free to subscribe to our
mailing list:

https://mail.python.org/mailman/listinfo/tkrad-discuss

or send an e-mail directly to: tkrad-discuss@python.org


**BUG REPORT**
--------------

In order to **track bugs** and fix them correctly, we'd like to hear
from you.

**If you encountered any problem** during the use of *tkRAD* lib,
please leave us a comment and tell us:

* environment:
    * which platform? (Windows, macOS, Linux)
    * which Python version? (2.7+, 3.2+)
    * which tkRAD version? (1.2, 1.3, 1.4...)
    * tkinter installed correctly? (yes/no)

* context:
    * when did it happen?
        * while trying wiki tutorial code samples?
        * while trying *tkRAD.easy.builder* features?
        * while trying to write your own app?

* traceback (optional):
    * are you sure it is *NOT* an XML source code mistype error?
    * could you copy/paste the console error text, please?
    * could you tell us few words about what happened?

**Whatever happened**, we'd like to know about it.

You will find an open issue **"It did *NOT* work for me!"** at:

https://github.com/tarball69/tkRAD/issues/6

**Thank you for contributing** to make *tkRAD* a better place for
everyone.

"""

) # end setup
